==> eightyone_1.7.20100104-2.tar.gz: eightyone-1.7.20100104/src/GenerateDialog.h <==
#ifndef GENERATEDIALOG_H
#define GENERATEDIALOG_H

/*
  EightyOne - A simple Sudoku solving game
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Integer.h>

class GenerateDialog : public Lum::Dlg::ActionDialog
{
private:
  struct Level
   {
     std::wstring label;
     size_t       points;

     Level(const std::wstring& level,
           size_t points);
   };

private:
  std::list<Level>      levels;
  Lum::Model::ActionRef commitAction;
  Lum::Model::SizeTRef  level;
  bool                  success;

public:
  GenerateDialog(size_t points);

  Lum::Object* GetContent();
  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);

  bool GetSuccess() const;
  size_t GetPoints() const;
};

extern bool ShowGenerateDialog(Lum::Dialog* parent, size_t& points);

#endif

==> eightyone_1.10.20101005-5.tar.gz: eightyone-1.10.20101005/src/GenerateDialog.h <==
#ifndef GENERATEDIALOG_H
#define GENERATEDIALOG_H

/*
  EightyOne - A simple Sudoku solving game
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Number.h>

class GenerateDialog : public Lum::Dlg::ActionDialog
{
private:
  struct Level
   {
     std::wstring label;
     size_t       points;

     Level(const std::wstring& level,
           size_t points);
   };

private:
  std::list<Level>      levels;
  Lum::Model::ActionRef commitAction;
  Lum::Model::SizeTRef  level;
  bool                  success;

public:
  GenerateDialog(size_t points);

  Lum::Object* GetContent();
  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);

  bool GetSuccess() const;
  size_t GetPoints() const;
};

extern bool ShowGenerateDialog(Lum::Dialog* parent, size_t& points);

#endif
